#! /bin/sh
#
#   GNUstep.sh.in
#
#   Shell initialization for the GNUstep environment.
#
#   Copyright (C) 1997 Free Software Foundation, Inc.
#
#   Author:  Scott Christley <scottc@net-community.com>
#
#   This file is part of the GNUstep Makefile Package.
#
#   This library is free software; you can redistribute it and/or
#   modify it under the terms of the GNU General Public License
#   as published by the Free Software Foundation; either version 2
#   of the License, or (at your option) any later version.
#   
#   You should have received a copy of the GNU General Public
#   License along with this library; see the file COPYING.LIB.
#   If not, write to the Free Software Foundation,
#   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#

#
# Set the GNUstep system root and local root
#
GNUSTEP_ROOT=/usr/lib/GNUstep
GNUSTEP_SYSTEM_ROOT=/usr/lib/GNUstep
if [ -z "$LIBRARY_COMBO" ]; then
  LIBRARY_COMBO=gnu-gnu-gnu-xgps
fi
export GNUSTEP_ROOT GNUSTEP_SYSTEM_ROOT LIBRARY_COMBO

GNUSTEP_LOCAL_ROOT=$GNUSTEP_ROOT/Local
GNUSTEP_NETWORK_ROOT=$GNUSTEP_ROOT/Network
GNUSTEP_USER_ROOT=~/GNUstep
export GNUSTEP_LOCAL_ROOT GNUSTEP_NETWORK_ROOT GNUSTEP_USER_ROOT

if [ -z "$GNUSTEP_BUILD_ROOT" ]; then
  GNUSTEP_MAKEFILES=$GNUSTEP_SYSTEM_ROOT/Makefiles
else
  GNUSTEP_MAKEFILES=$GNUSTEP_BUILD_ROOT/Makefiles
fi
export GNUSTEP_MAKEFILES

#
# Determine the host information
#
if [ -z "$GNUSTEP_HOST" ]; then
  pushd /tmp >> /dev/null
  GNUSTEP_HOST=`$GNUSTEP_MAKEFILES/config.guess`
  GNUSTEP_HOST=`$GNUSTEP_MAKEFILES/config.sub $GNUSTEP_HOST`
  popd >> /dev/null
fi
GNUSTEP_HOST_CPU=`$GNUSTEP_MAKEFILES/cpu.sh $GNUSTEP_HOST`
GNUSTEP_HOST_VENDOR=`$GNUSTEP_MAKEFILES/vendor.sh $GNUSTEP_HOST`
GNUSTEP_HOST_OS=`$GNUSTEP_MAKEFILES/os.sh $GNUSTEP_HOST`

# Clean the host
GNUSTEP_HOST_CPU=`$GNUSTEP_MAKEFILES/clean_cpu.sh $GNUSTEP_HOST_CPU`
GNUSTEP_HOST_VENDOR=`$GNUSTEP_MAKEFILES/clean_vendor.sh $GNUSTEP_HOST_VENDOR`
GNUSTEP_HOST_OS=`$GNUSTEP_MAKEFILES/clean_os.sh $GNUSTEP_HOST_OS`

export GNUSTEP_HOST GNUSTEP_HOST_CPU GNUSTEP_HOST_VENDOR GNUSTEP_HOST_OS

#
# the rest of this file is only executed, if the core already is installed.
#
if [ -z "$GNUSTEP_BUILD_ROOT" ]; then

#
# Add the GNUstep tools directories to the path
#
if [ -z "$GNUSTEP_PATHPREFIX_LIST" ]; then
  GNUSTEP_PATHPREFIX_LIST=$GNUSTEP_USER_ROOT:$GNUSTEP_LOCAL_ROOT:$GNUSTEP_SYSTEM_ROOT:$GNUSTEP_NETWORK_ROOT
  export GNUSTEP_PATHPREFIX_LIST
fi # [ -z "$GNUSTEP_PATHPREFIX_LIST" ]

tmp_IFS="$IFS"
IFS=:
temp_path=
for dir in $GNUSTEP_PATHPREFIX_LIST; do
  temp_path=$temp_path$dir/Tools:
  temp_path=$temp_path$dir/Tools/${GNUSTEP_HOST_CPU}/${GNUSTEP_HOST_OS}:
done
IFS="$tmp_IFS"
if ( echo ${PATH}|fgrep -v "${temp_path}" >/dev/null ); then
  PATH=$temp_path$PATH
fi

if [ -z "$MANPATH" ]; then
  MANPATH=${GNUSTEP_SYSTEM_ROOT}/Library/man:/usr/local/man:/usr/man
else
  if ( echo ${MANPATH}|fgrep -v "${GNUSTEP_SYSTEM_ROOT}/Library/man" >/dev/null ); then
    MANPATH=${GNUSTEP_SYSTEM_ROOT}/Library/man:${MANPATH}
  fi
fi

. $GNUSTEP_MAKEFILES/ld_lib_path.sh

#
# Perform any user initialization
#
if [ -f ~/.GNUstep/GNUstep.sh ]
then
  . ~/.GNUstep/GNUstep.sh
fi

#
# Run 'make_services' in background if possible - updates cache of services
# and applications/file-extensions known to the applications.
#
if [ -x $GNUSTEP_SYSTEM_ROOT/Tools/make_services ]
then
  $GNUSTEP_SYSTEM_ROOT/Tools/make_services &
fi

fi # [ -z "$GNUSTEP_BUILD_ROOT" ]


#
# Set the Java CLASSPATH
#

if [ -z "$CLASSPATH" ]; then
  MY_CLASSPATH=.
else
  MY_CLASSPATH=$CLASSPATH:.
fi # [ -z "$CLASSPATH" ]

CLASSPATH=$GNUSTEP_SYSTEM_ROOT/Java/:$GNUSTEP_USER_ROOT/Java/:$GNUSTEP_LOCAL_ROOT/Java/:$GNUSTEP_NETWORK_ROOT/Java/:$MY_CLASSPATH
export CLASSPATH

